(function (GCN) {

	'use strict';

	/**
	 * Only grows, never shrinks.
	 * @private
	 * @type {number}
	 */
	var uniqueIdCounter = 0;

	/**
	 * Generates a unique id with an optional prefix.
	 *
	 * The returned value is only unique among other returned values,
	 * not globally.
	 *
	 * @public
	 * @param {string}
	 *        Optional prefix for the id to be generated.
	 * @return {string}
	 *        Never the same string more than once.
	 */
	function uniqueId(prefix) {
		return (prefix || '') + (++uniqueIdCounter);
	}

	function escapePropertyName(name) {
		return name.replace(/\./g, '\\.');
	}

	GCN.uniqueId = uniqueId;
	GCN.escapePropertyName = escapePropertyName;

}(GCN));
